@@ -15,6 +15,7 @@
 #include "fu-wac-module-bluetooth-id9.h"
 #include "fu-wac-module-bluetooth.h"
 #include "fu-wac-module-scaler.h"
+#include "fu-wac-module-sub-cpu.h"
 #include "fu-wac-module-touch-id7.h"
 #include "fu-wac-module-touch.h"
 #include "fu-wac-struct.h"
@@ -790,6 +791,14 @@ fu_wac_device_add_modules(FuWacDevice *self, GError **error)
 			fu_device_set_summary(FU_DEVICE(module), "ID9");
 			fu_device_set_version_u16(FU_DEVICE(module), ver);
 			break;
+		case FU_WAC_MODULE_FW_TYPE_SUB_CPU:
+			module = fu_wac_module_sub_cpu_new(FU_DEVICE(self));
+			name = g_strdup_printf("%s [Sub CPU Module]",
+					       fu_device_get_name(FU_DEVICE(self)));
+			fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module));
+			fu_device_set_name(FU_DEVICE(module), name);
+			fu_device_set_version_raw(FU_DEVICE(module), ver);
+			break;
 		case FU_WAC_MODULE_FW_TYPE_MAIN:
 			fu_device_set_version_u16(FU_DEVICE(self), ver);
 			break;
@@ -873,6 +882,7 @@ fu_wac_device_init(FuWacDevice *self)
 	fu_device_add_icon(FU_DEVICE(self), "input-tablet");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_FLAGS);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_BCD);
 	fu_device_set_install_duration(FU_DEVICE(self), 10);
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
