@@ -36,6 +36,10 @@
 #include "fu-release.h"
 #include "fu-security-attrs-private.h"
 
+#ifdef HAVE_MALLOC_H
+#include <malloc.h>
+#endif
+
 static void
 fu_daemon_finalize(GObject *obj);
 
@@ -53,6 +57,7 @@ struct _FuDaemon {
 	guint owner_id;
 	guint process_quit_id;
 	FuEngine *engine;
+	guint housekeeping_id;
 	gboolean update_in_progress;
 	gboolean pending_stop;
 	FuDaemonMachineKind machine_kind;
@@ -61,10 +66,40 @@ struct _FuDaemon {
 
 G_DEFINE_TYPE(FuDaemon, fu_daemon, G_TYPE_OBJECT)
 
+#define FU_DAEMON_HOUSEKEEPING_DELAY 10 /* seconds */
+
+static gboolean
+fu_daemon_schedule_housekeeping_cb(gpointer user_data)
+{
+	FuDaemon *self = FU_DAEMON(user_data);
+
+#ifdef HAVE_MALLOC_TRIM
+	/* drop heap except one page */
+	malloc_trim(0);
+#endif
+
+	/* success */
+	self->housekeeping_id = 0;
+	return G_SOURCE_REMOVE;
+}
+
+static void
+fu_daemon_schedule_housekeeping(FuDaemon *self)
+{
+	if (self->update_in_progress)
+		return;
+	if (self->housekeeping_id != 0)
+		g_source_remove(self->housekeeping_id);
+	self->housekeeping_id = g_timeout_add_seconds(FU_DAEMON_HOUSEKEEPING_DELAY,
+						      fu_daemon_schedule_housekeeping_cb,
+						      self);
+}
+
 void
 fu_daemon_start(FuDaemon *self)
 {
 	g_return_if_fail(FU_IS_DAEMON(self));
+	fu_daemon_schedule_housekeeping(self);
 	g_main_loop_run(self->loop);
 }
 
@@ -92,6 +127,7 @@ fu_daemon_engine_changed_cb(FuEngine *engine, FuDaemon *self)
 				      "Changed",
 				      NULL,
 				      NULL);
+	fu_daemon_schedule_housekeeping(self);
 }
 
 static void
@@ -110,6 +146,7 @@ fu_daemon_engine_device_added_cb(FuEngine *engine, FuDevice *device, FuDaemon *s
 				      "DeviceAdded",
 				      g_variant_new_tuple(&val, 1),
 				      NULL);
+	fu_daemon_schedule_housekeeping(self);
 }
 
 static void
@@ -128,6 +165,7 @@ fu_daemon_engine_device_removed_cb(FuEngine *engine, FuDevice *device, FuDaemon
 				      "DeviceRemoved",
 				      g_variant_new_tuple(&val, 1),
 				      NULL);
+	fu_daemon_schedule_housekeeping(self);
 }
 
 static void
@@ -146,6 +184,7 @@ fu_daemon_engine_device_changed_cb(FuEngine *engine, FuDevice *device, FuDaemon
 				      "DeviceChanged",
 				      g_variant_new_tuple(&val, 1),
 				      NULL);
+	fu_daemon_schedule_housekeeping(self);
 }
 
 static void
@@ -831,7 +870,7 @@ fu_daemon_install_with_helper_device(FuMainAuthHelper *helper,
 	}
 	if (!fu_engine_requirements_check(self->engine,
 					  release,
-					  helper->flags | FWUPD_INSTALL_FLAG_FORCE,
+					  helper->flags | FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS,
 					  &error_local)) {
 		if (!g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND)) {
 			g_debug("first pass requirement on %s:%s failed: %s",
@@ -844,6 +883,7 @@ fu_daemon_install_with_helper_device(FuMainAuthHelper *helper,
 	}
 
 	/* sync update message from CAB */
+	fu_device_ensure_from_component(device, component);
 	fu_device_incorporate_from_component(device, component);
 
 	/* install each intermediate release */
@@ -1869,6 +1909,10 @@ fu_daemon_daemon_method_call(GDBusConnection *connection,
 			return;
 		}
 
+		/* relax these */
+		if (fu_engine_config_get_ignore_requirements(fu_engine_get_config(self->engine)))
+			helper->flags |= FWUPD_INSTALL_FLAG_IGNORE_REQUIREMENTS;
+
 		/* install all the things in the store */
 		helper->client = fu_client_list_register(self->client_list, sender);
 		helper->client_sender_changed_id =
@@ -2453,6 +2497,8 @@ fu_daemon_finalize(GObject *obj)
 		g_object_unref(self->client_list);
 	if (self->process_quit_id != 0)
 		g_source_remove(self->process_quit_id);
+	if (self->housekeeping_id != 0)
+		g_source_remove(self->housekeeping_id);
 	if (self->loop != NULL)
 		g_main_loop_unref(self->loop);
 	if (self->owner_id > 0)
